[−][src]Struct pixel_widgets::backend::wgpu::Ui
Wrapper for Ui that adds wgpu rendering.
Requires the "wgpu" feature.
Implementations
impl<M: Model, E: 'static + EventLoop<Command<M::Message>>, L: 'static + Loader> Ui<M, E, L>[src]
pub fn new(
model: M,
event_loop: E,
loader: L,
viewport: Rectangle,
format: TextureFormat,
device: &Device
) -> Self[src]
model: M,
event_loop: E,
loader: L,
viewport: Rectangle,
format: TextureFormat,
device: &Device
) -> Self
Constructs a new Ui using the default style.
This is not recommended as the default style is very empty and only renders white text.
pub fn draw<'a>(
&'a mut self,
device: &Device,
queue: &Queue,
render_pass: &mut RenderPass<'a>
)[src]
&'a mut self,
device: &Device,
queue: &Queue,
render_pass: &mut RenderPass<'a>
)
Generate a DrawList for the view.
Methods from Deref<Target = Ui<M, E, L>>
pub async fn set_stylesheet<U: AsRef<str>>(
&mut self,
url: U
) -> Result<(), Error>[src]
&mut self,
url: U
) -> Result<(), Error>
Constructs a new Ui asynchronously by first fetching a stylesheet from a
.pwss data source.
pub fn replace_stylesheet(&mut self, style: Arc<Style>)[src]
Replace the current stylesheet with a loaded new stylesheet
pub fn reload_stylesheet<U: 'static + AsRef<str> + Send>(&mut self, url: U)[src]
Replace the current stylesheet with a new one
pub fn graphics(&self) -> Graphics<L>[src]
Get a Graphics loader
pub fn resize(&mut self, viewport: Rectangle)[src]
Resizes the viewport. This forces the view to be rerendered.
pub fn command(&mut self, command: Command<M::Message>)[src]
Updates the model after a Command has resolved.
pub fn update(&mut self, message: M::Message)[src]
Updates the model with a message. This forces the view to be rerendered.
pub fn event(&mut self, event: Event)[src]
Handles an Event.
pub fn needs_redraw(&self) -> bool[src]
Returns true if the ui needs to be redrawn. If the ui doesn't need to be redrawn the
Commands from the last draw may be used again.
pub fn draw(&mut self) -> DrawList[src]
Generate a DrawList for the view.