Update

Enum Update 

pub enum Update {
    TextureSubresource {
        id: usize,
        offset: [u32; 2],
        size: [u32; 2],
        data: Vec<u8>,
    },
    Texture {
        id: usize,
        size: [u32; 2],
        data: Vec<u8>,
        atlas: bool,
    },
}
An update of the available texture data. The backend is responsible for uploading the provided data to the GPU.

Variants



TextureSubresource

An existing texture is updated.

Fields

id: usize

The id of the texture that needs to be updated

offset: [u32; 2]

Offset from the left top corner of the texture.

size: [u32; 2]

Size of the rect described by data

data: Vec<u8>

The texel data of the updated rect. 4 elements per pixel.



Texture

A new texture is introduced.

Fields

id: usize

The id for the new texture. This is the id that will later be used to identify which texture the backend has to use whenever applicable.

size: [u32; 2]

Size of the texture

data: Vec<u8>

The texel data of the texture. 4 elements per pixel

atlas: bool

Whether the texture will be used as atlas. true means the texture might be updated later with TextureSubresource, while false means the texture is immutable.