[−][src]Struct pixel_widgets::draw::DrawList
A collection of data needed to render the ui.
Fields
updates: Vec<Update>A list of texture updates that need to be uploaded before rendering.
vertices: Vec<Vertex>The vertex buffer used for this frame.
commands: Vec<Command>A list of draw commands that use the vertices buffer.