[−][src]Trait pixel_widgets::loader::Loader
A way to load URLs from a data source.
Included implementations:
PathBuf, loads data from disk using thePathBufas working directory.
Associated Types
type Load: Future<Output = Result<Vec<u8>, Self::Error>> + Send[src]
A future returned when calling load.
type Wait: Future<Output = Result<(), Self::Error>> + Send[src]
A future returned when calling wait.
type Error: 'static + Error + Send + Sync[src]
Error returned by the loader when the request failed.
Required methods
pub fn load(&self, url: impl AsRef<str>) -> Self::Load[src]
Asynchronously load a resource located at the given url
pub fn wait(&self, url: impl AsRef<str>) -> Self::Wait[src]
Wait for a resource to be modified externally.