[−][src]Enum pixel_widgets::stylesheet::Selector
A stylesheet selector, which widgets have to match against.
Variants
Widget(SelectorWidget)Match a widget
WidgetDirectChild(SelectorWidget)Match a widget that is a direct child of the parent
WidgetDirectAfter(SelectorWidget)Match a widget that follows directly after the previous widget
WidgetAfter(SelectorWidget)Match a widget that follows after a previous widget
Match the nth child widget modulo a number
Match the nth child widget counted from the last child widget modulo a number
Nth(usize)Match the nth child widget
NthLast(usize)Match the nth child widget counted from the last child widget
Match widgets that are the only child of their parent
Class(String)Match widgets that have a class
State(StyleState<String>)Match widgets that are in a state
Invert the nested selector
Implementations
impl Selector[src]
pub fn match_sibling(&self, direct: bool, widget: &str) -> Option<bool>[src]
Match a sibling widget of the current rule. If this selector is not a sibling selector None is returned.
pub fn match_child(&self, direct: bool, widget: &str) -> Option<bool>[src]
Match a child widget of the current rule. If this selector is not a child selector None is returned.
pub fn match_meta<S: AsRef<str>>(
&self,
state: &[StyleState<S>],
class: &str,
n: usize,
len: usize
) -> Option<bool>[src]
&self,
state: &[StyleState<S>],
class: &str,
n: usize,
len: usize
) -> Option<bool>
Match parameters of the widget matched by the current rule.
If this selector is not a meta selector None is returned.