[][src]Enum pixel_widgets::stylesheet::StyleState

pub enum StyleState<S: AsRef<str>> {
    Hover,
    Pressed,
    Checked,
    Disabled,
    Open,
    Closed,
    Drag,
    Drop,
    Custom(S),
}

Widget states

Variants

Hover

When the mouse is over the widget

Pressed

When the mouse is clicking on the widget

Checked

When the widget is in a checked state (checkbox, radio button)

Disabled

When a widget is disabled

Open

When a widget in an expanded state

Closed

When a widget is in a collapsed state

Drag

When a drag widget is being dragged

Drop

When a drop widget accepts a dragged widget before it's dropped

Custom(S)

Custom state for custom widgets