[−][src]Struct pixel_widgets::stylesheet::Style
A style loaded from a .pwss file.
Implementations
impl Style[src]
pub fn new(cache_size: usize, cache_offset: usize) -> Self[src]
Construct a new default style
pub async fn load<U: AsRef<str>, L: Loader>(
loader: &L,
url: U,
cache_size: usize,
cache_offset: usize
) -> Result<Self, Error>[src]
loader: &L,
url: U,
cache_size: usize,
cache_offset: usize
) -> Result<Self, Error>
Asynchronously load a stylesheet from a .pwss file. See the module documentation on how to write .pwss files.
pub async fn load_from_memory<L: Loader>(
bytes: &[u8],
loader: &L,
cache_size: usize,
cache_offset: usize
) -> Result<Self, Error>[src]
bytes: &[u8],
loader: &L,
cache_size: usize,
cache_offset: usize
) -> Result<Self, Error>
Asynchronously load a stylesheet from a .pwss file already in memory. See the module documentation on how to write .pwss files.