[−][src]Struct pixel_widgets::tracker::ManagedState
An Widget state tracker.
Implementations
impl<Id: Eq + Clone> ManagedState<Id>[src]
pub fn tracker(&mut self) -> ManagedStateTracker<'_, Id>[src]
Retrieve a ManagedStateTracker that can be used to build a ui.
Normally you will call this function at the start of your
view implementation.