[−][src]Trait pixel_widgets::Model
A model that keeps track of the state of your GUI. Serves to control the behaviour and DOM of your GUI.
Styling is handled separately. Once you implemented a model, you can run your GUI using a Ui.
Examples
The examples in this repository all implement some kind of Model, check them out if you just want to read
some code.
Associated Types
Loading content...Required methods
pub fn update(&mut self, message: Self::Message) -> Vec<Command<Self::Message>>[src]
Called when a message is fired from the view or some other source. This is where you should update your gui state.