[−][src]Struct pixel_widgets::cache::Cache
A cache for textures and text
Implementations
impl Cache[src]
pub fn new(size: usize, offset: usize) -> Cache[src]
Create a new cache. Size is the width and height of textures in pixels. Offset is the offset to apply to texture ids
pub fn take_updates(&mut self) -> Vec<Update>[src]
Take updates for the texture system from the cache