[−][src]Struct pixel_widgets::draw::Patch
9 patch data on top of an Image, which is used to create dynamically stretchable images.
Fields
image: ImageThe Image this Patch operates on.
h_stretch: SmallVec<[(f32, f32); 2]>Horizontally stretchable regions in the 9 patch image. Every element is a pair of begin and end of the stretchable region. Defined in relative coordinates: 0.0 is the left side of the image, 1.0 is the right side of the image.
v_stretch: SmallVec<[(f32, f32); 2]>Vertically stretchable regions in the 9 patch image. Every element is a pair of begin and end of the stretchable region. Defined in relative coordinates: 0.0 is the top side of the image, 1.0 is the bottom side of the image.
h_content: (f32, f32)Horizontal content area in the 9 patch image. Content can be placed in the region defined here. Defined in relative coordinates: 0.0 is the left side of the image, 1.0 is the right side of the image.
v_content: (f32, f32)Vertical content area in the 9 patch image. Content can be placed in the region defined here. Defined in relative coordinates: 0.0 is the top side of the image, 1.0 is the bottom side of the image.
Implementations
impl Patch[src]
pub fn measure_with_content(&self, measured_content: Rectangle) -> Rectangle[src]
Extend measured_content so it exactly fills the content rect of this patch.
pub fn margin(&self) -> Rectangle[src]
Returns the padding of the 9 patch
pub fn minimum_size(&self) -> (f32, f32)[src]
The size of the patch when the content rect is zero sized.
pub fn content_rect(&self, span: Rectangle) -> Rectangle[src]
The content rect for a give size