[−][src]Enum pixel_widgets::stylesheet::StyleState
Widget states
Variants
When the mouse is over the widget
When the mouse is clicking on the widget
When the widget is in a checked state (checkbox, radio button)
When a widget is disabled
When a widget in an expanded state
When a widget is in a collapsed state
When a drag widget is being dragged
When a drop widget accepts a dragged widget before it's dropped
Custom state for custom widgets